@@ -24,7 +24,7 @@
 #include <kconfiggroup.h>
 #include <kdesktopfile.h>
 #include <kmimetypetrader.h>
-#include <kservicefactory.h>
+#include <kservicefactory_p.h>
 #include <qtemporaryfile.h>
 #include <qtest.h>
 #include "kmimeassociations.h"
@@ -35,7 +35,8 @@
 class FakeServiceFactory : public KServiceFactory
 {
 public:
-    FakeServiceFactory() : KServiceFactory() {}
+    FakeServiceFactory(KSycoca *db) : KServiceFactory(db) {}
+    ~FakeServiceFactory();
 
     virtual KService::Ptr findServiceByMenuId(const QString &name)
     {
@@ -111,6 +112,9 @@ private Q_SLOTS:
         QStandardPaths::enableTestMode(true);
         qputenv("XDG_CURRENT_DESKTOP", "KDE");
 
+        extern KSERVICE_EXPORT bool kservice_require_kded;
+        kservice_require_kded = false;
+
         m_localConfig = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1Char('/');
         QDir(m_localConfig).removeRecursively();
         QVERIFY(QDir().mkpath(m_localConfig));
@@ -159,7 +163,7 @@ private Q_SLOTS:
         // Create factory on the heap and don't delete it. This must happen after
         // Sycoca is built, in case it did not exist before.
         // It registers to KSycoca, which deletes it at end of program execution.
-        KServiceFactory *factory = new FakeServiceFactory;
+        KServiceFactory *factory = new FakeServiceFactory(KSycoca::self());
         QCOMPARE(KServiceFactory::self(), factory); // ctor sets s_self
 
         // For debugging: print all services and their storageId
@@ -214,7 +218,7 @@ private Q_SLOTS:
     void testParseSingleFile()
     {
         KOfferHash offerHash;
-        KMimeAssociations parser(offerHash);
+        KMimeAssociations parser(offerHash, KServiceFactory::self());
 
         QTemporaryFile tempFile;
         QVERIFY(tempFile.open());
@@ -262,7 +266,7 @@ private Q_SLOTS:
     void testGlobalAndLocalFiles()
     {
         KOfferHash offerHash;
-        KMimeAssociations parser(offerHash);
+        KMimeAssociations parser(offerHash, KServiceFactory::self());
 
         // Write global file
         QTemporaryFile tempFileGlobal;
@@ -507,6 +511,10 @@ private:
     ExpectedResultsMap removedApps;
 };
 
+FakeServiceFactory::~FakeServiceFactory()
+{
+}
+
 QTEST_GUILESS_MAIN(KMimeAssociationsTest)
 
 #include "kmimeassociationstest.moc"
